@@ -23,6 +23,7 @@ import sys
 import glob
 import codecs
 import shutil
+import filecmp
 
 try:
     from urlparse import urljoin
@@ -44,9 +45,10 @@ class Renderer(object):
             self.config["theme"] = "default"
 
         if "pages" not in self.config:
-            self.pages = [{"file": "pages/*.md",
-                           "template": "page.tmpl",
-                           "path": "/"}]
+            self.config['pages'] = []
+
+        if "assets" not in self.config:
+            self.config['assets'] = []
 
         self._targets = {}
         self._page_maps = []
@@ -73,7 +75,7 @@ class Renderer(object):
         theme_assets_path = os.path.join(theme_path, "assets")
 
         if not os.path.isdir(theme_path):
-            # logging.critical("This doesn't look like a wok site. Aborting.")
+            # logging.critical("Not found theme directory %s. Aborting.")
             print("Not found theme directory %s. Aborting." %
                   theme_path)
             sys.exit(1)
@@ -156,8 +158,12 @@ class Renderer(object):
                     os.remove(output_file_path)
 
                 print("rendering %s" % page)
-
-                text = p.render()
+                text = p.render(author=self.config['author'],
+                                title=self.config['title'],
+                                url=self.config['url'],
+                                email=self.config['email'],
+                                keywords=self.config['keywords'],
+                                description=self.config['description'])
 
                 if text is not None:
                     with codecs.open(output_file_path, 'w', encoding="utf-8") as fp:
@@ -166,6 +172,10 @@ class Renderer(object):
             self._page_maps.append({'location': output_filename,
                                     'modified': p.mtime})
 
+    def _build_assets(self):
+        # TODO
+        pass
+
     def _copy_assets(self):
         theme_path = os.path.join("themes", self.config["theme"])
         theme_assets_path = os.path.join(theme_path, "assets")
@@ -177,6 +187,15 @@ class Renderer(object):
         if not os.path.isdir(output_assets_dir):
             os.mkdir(output_assets_dir)
 
+        favicon_path = os.path.join(theme_path, 'favicon.ico')
+        output_favicon_path = os.path.join(self.output_dir, "favicon.ico")
+
+        if os.path.exists(favicon_path):
+            if not os.path.exists(output_favicon_path) or not filecmp.cmp(favicon_path, output_favicon_path):
+                print("cp %s %s" % (favicon_path, output_favicon_path))
+                shutil.copy(favicon_path, output_favicon_path)
+                shutil.copystat(favicon_path, output_favicon_path)
+
         weak_tree_copy(theme_assets_path, output_assets_dir)
         weak_tree_copy(page_assets_path, output_assets_dir)
 
@@ -190,7 +209,6 @@ class Renderer(object):
                 shutil.copystat(robots_txt_path, output_robots_txt_path)
 
     def _generate_sitemap(self):
-
         if 'url' in self.config:
             site_url = self.config['url']
         else:
